@@ -30,10 +30,7 @@ class HtmlDerivative(Derivative):
 
     def do_task_per_message(self, message):
 
-        errors = {}
-        errors["msg"] = []
-        errors["stack_trace"] = []
-
+        errors = []
         try:
 
             if message.Derivatives_Path is None:
@@ -71,7 +68,6 @@ class HtmlDerivative(Derivative):
             desc = "Error creating HTML derivative"
             errors = common.handle_error(errors, e, desc)
 
-        message.Error.extend(errors["msg"])
-        message.StackTrace.extend(errors["stack_trace"])
+        message.Errors.extend(errors)
 
         return message
