@@ -2,6 +2,7 @@ from structlog import get_logger
 import mailbox
 import os
 import mailbagit.helper.common as common
+import mailbagit.helper.derivative as derivative
 from email.mime.multipart import MIMEMultipart
 from email.mime.base import MIMEBase
 from email.mime.text import MIMEText
@@ -34,10 +35,7 @@ class MboxDerivative(Derivative):
 
     def do_task_per_message(self, message):
 
-        errors = {}
-        errors["msg"] = []
-        errors["stack_trace"] = []
-
+        errors = []
         try:
 
             try:
@@ -112,6 +110,12 @@ class MboxDerivative(Derivative):
                             desc = "Error writing body for MBOX derivative"
                             errors = common.handle_error(errors, e, desc)
 
+                        # Get list of <img> files that might reference attachments
+                        if message.HTML_Body:
+                            inline_files = derivative.inlineAttachments(message.HTML_Body, message.HTML_Encoding)
+                        else:
+                            inline_files = {}
+
                         # Attachments
                         try:
                             for attachment in message.Attachments:
@@ -159,7 +163,6 @@ class MboxDerivative(Derivative):
             desc = "Error creating MBOX derivative"
             errors = common.handle_error(errors, e, desc)
 
-        message.Error.extend(errors["msg"])
-        message.StackTrace.extend(errors["stack_trace"])
+        message.Errors.extend(errors)
 
         return message
