@@ -29,10 +29,7 @@ class TxtDerivative(Derivative):
 
     def do_task_per_message(self, message):
 
-        errors = {}
-        errors["msg"] = []
-        errors["stack_trace"] = []
-
+        errors = []
         try:
 
             out_dir = os.path.join(self.txt_dir, message.Derivatives_Path)
@@ -59,7 +56,6 @@ class TxtDerivative(Derivative):
             desc = "Error creating plain text derivative"
             errors = common.handle_error(errors, e, desc)
 
-        message.Error.extend(errors["msg"])
-        message.StackTrace.extend(errors["stack_trace"])
+        message.Errors.extend(errors)
 
         return message
