@@ -65,9 +65,7 @@ class WarcDerivative(Derivative):
 
     def do_task_per_message(self, message):
 
-        errors = {}
-        errors["msg"] = []
-        errors["stack_trace"] = []
+        errors = []
 
         try:
 
@@ -136,7 +134,6 @@ class WarcDerivative(Derivative):
             desc = "Error creating WARC derivative"
             errors = common.handle_error(errors, e, desc)
 
-        message.Error.extend(errors["msg"])
-        message.StackTrace.extend(errors["stack_trace"])
+        message.Errors.extend(errors)
 
         return message
