@@ -59,9 +59,7 @@ if not skip_registry:
                         yield None
                         continue
                     attachments = []
-                    errors = {}
-                    errors["msg"] = []
-                    errors["stack_trace"] = []
+                    errors = []
                     try:
                         messageObj = folder.get_sub_message(index)
 
@@ -201,7 +199,7 @@ if not skip_registry:
                             errors = common.handle_error(errors, e, desc)
 
                         message = Email(
-                            Error=errors["msg"],
+                            Errors=errors,
                             Message_ID=format.parse_header(headers["Message-ID"]),
                             Original_File=originalFile,
                             Message_Path=messagePath,
@@ -220,13 +218,12 @@ if not skip_registry:
                             Text_Encoding=text_encoding,
                             Message=None,
                             Attachments=attachments,
-                            StackTrace=errors["stack_trace"],
                         )
 
                     except (Exception) as e:
                         desc = "Error parsing message"
                         errors = common.handle_error(errors, e, desc)
-                        message = Email(Error=errors["msg"], StackTrace=errors["stack_trace"])
+                        message = Email(Errors=errors)
 
                     yield message
 
@@ -235,11 +232,16 @@ if not skip_registry:
                 for folder_index in range(folder.number_of_sub_folders):
                     subfolder = folder.get_sub_folder(folder_index)
                     yield from self.folders(subfolder, path + "/" + subfolder.name, originalFile)
-            # else:
-            # if not self.iteration_only:
-            # This is an email folder that does not contain any messages.
-            # We are currently ignoring these per issue #117
-            # log.warn("Empty folder " + folder.name + " not handled.")
+            else:
+                if not self.iteration_only:
+                    if not folder.number_of_sub_messages:
+                        # This is an email folder that does not contain any messages.
+                        # Currently, we are only warning about empty folders pending the possibility of
+                        # a better solution described in #117
+                        desc = "Folder '" + path + "' contains no messages and will be ignored"
+                        # handle_error() won't work here as-is because the errors list is added to the Message model
+                        # errors = common.handle_error(errors, None, desc, "warn")
+                        log.warn(desc + ".")
 
         def messages(self):
             companion_files = []
@@ -275,11 +277,16 @@ if not skip_registry:
                     if folder.number_of_sub_folders:
                         # call recursive function to parse email folder
                         yield from self.folders(folder, folder.name, originalFile)
-                    # else:
-                    # if not self.iteration_only:
-                    # This is an email folder that does not contain any messages.
-                    # We are currently ignoring these per issue #117
-                    # log.warn("Empty folder " + folder.name + " not handled.")
+                    else:
+                        if not self.iteration_only:
+                            # This is an email folder that does not contain any messages.
+                            # Currently, we are only warning about empty folders pending the possibility of
+                            # a better solution described in #117
+                            desc = "Folder '" + folder.name + "' contains no messages and will be ignored"
+                            # handle_error() won't work here as-is because the errors list is added to the Message model
+                            # errors = common.handle_error(errors, None, desc, "warn")
+                            log.warn(desc + ".")
+
                 pst.close()
 
                 # Move PST to new mailbag directory structure
